<?php
/**
 *
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace TrainingJsUnit4\SkeletonPiratesForm\Controller\Adminhtml\Grid;

use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Api\DataObjectHelper;

class Save extends \Magento\Backend\App\Action
{
    protected $dataPersistor;

    protected $model;

    protected $dataObjectHelper;

    /**
     * @var \Magento\Eav\Model\Config
     */
    private $eavConfig;

    public function __construct(
        Context $context,
        \Magento\Framework\Registry $coreRegistry,
        DataPersistorInterface $dataPersistor,
        \TrainingJsUnit4\PiratesForm\Model\PirateFactory $pirateFactory,
        DataObjectHelper $dataObjectHelper,
        \Magento\Eav\Model\Config $eavConfig = null
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->model = $pirateFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        $this->eavConfig = $eavConfig;
        parent::__construct($context);
    }

    public function execute()
    {
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        $data = $this->getRequest()->getPostValue();
        if ($data) {
            $id = $this->getRequest()->getParam('pirate_id');

            if (empty($data['pirate_id'])) {
                $data['pirate_id'] = null;
            }
            $model = $this->model->create()->load($id);

            if (!$model->getPirateId() && $id) {
                $this->messageManager->addError(__('No longer exists.'));
                return $resultRedirect->setPath('*/*/');
            }

//            if (isset($data['picture']) && is_array($data['picture'])) {
//                if (!empty($data['picture']['delete'])) {
//                    $data['picture'] = null;
//                } else {
//                    if (isset($data['picture'][0]['name']) && isset($data['picture'][0]['tmp_name'])) {
//                        $data['picture'] = $data['picture'][0]['name'];
//                    } else {
//                        unset($data['picture']);
//                    }
//                }
//            }

            $model->setData($data);
            try {
                $model->save();

                $this->messageManager->addSuccess(__('You saved the entity.'));
                $this->dataPersistor->clear('pirates');

                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/edit', ['pirate_id' => $model->getPirateId()]);
                }
                return $resultRedirect->setPath('*/*/');
            } catch (LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the entity.'));
            }

            $this->dataPersistor->set('pirates', $data);
            return $resultRedirect->setPath('*/*/edit', ['pirate_id' => $this->getRequest()->getParam('pirate_id')]);
        }
        return $resultRedirect->setPath('*/*/');
    }

    public function imagePreprocessing($data)
    {
        if (is_array($data))
            return array_shift($data['picture'])['url'];



//        $entityType = $this->eavConfig->getEntityType('pirates');
//
//        foreach ($entityType->getAttributeCollection() as $attributeModel) {
//            $attributeCode = $attributeModel->getAttributeCode();
//            $backendModel = $attributeModel->getBackend();
//
//            if (isset($data[$attributeCode])) {
//                continue;
//            }
//
//            if (!$backendModel instanceof \Magento\Catalog\Model\Category\Attribute\Backend\Image) {
//                continue;
//            }
//
//            $data[$attributeCode] = false;
//        }
//
//        return $data;
    }
}
